History — RocketCEA 1.0.5 documentation

# History

## GitHub Log

- July 29, 2019
    - (by: sonofeft)

        - Major Overhaul of f2py usage

- July 6, 2019
    - (by: sonofeft and stepbot)

        - Begin to support MacOS (Darwin)

- Mar 26, 2019
    - (by: sonofeft)

        - Added Windows install fix info to docs

- Oct 22, 2018
    - (by: sonofeft)

        - added help for bad MinGW path error

- Oct 21, 2018
    - (by: sonofeft)

        - full instructions to recompile with gfortran

- Oct 20, 2018
    - (by: sonofeft)

        - Identified MinGW library issue in docs

        - Updated quickstart to show warning about recent python requiring user to run as administrator

- Aug 12, 2018
    - (by: sonofeft)

        - modify .gitattributes to make project show as python

        - added .gitattributes

- May 30, 2018
    - (by: sonofeft)

        - Reinstated Travis CI

        - matplotlib fix for Travis CI

            added: matplotlib.use(‘Agg’)

        - try apt packages on travis ci

        - try conda on travis ci

        - try some pip fixes to travis ci

        - try apt-get in travis build

        - Removed Travis-CI

            Need to solve missing libgfortran.so.3 import error on Travis CI

        - Developed code first commit

        - Revert “Initial commit”

            This reverts commit e06031f0a5c0244d944fc3b1f4a3ed987579a2a7.

    - (by: Charlie Taylor)

        - Initial commit

- May 29, 2018
    - (by: Charlie Taylor)

        - Verified operation on multiple platforms.

- May 13, 2018
    - (by: Charlie Taylor)

        - First Created RocketCEA with PyHatch

- 2005 - 2015
    - (by: Charlie Taylor)

        - Added enhancements to CEA interface.

- 2005
    - (by: Charlie Taylor)

        - Modified CEA2.f into py_cea.f so that f2py could build a python module

## PyHatch

RocketCEA Framework Created by: PyHatch on May 13, 2018

(PyHatch Initializes Files And Directory Structures For New Python Projects.)

See PyHatch Docs at: http://pyhatch.readthedocs.org/en/latest/